##  Use the Onboarding Dashboard for Fact Sheet Owners
The onboarding dashboard for fact sheet owners provides curated learning resources and quick access to assigned fact sheets and action items. These help fact sheet owners get familiar with SAP LeanIX and their responsibilities within the tool, focusing on data collection and maintenance. By using the dashboard, fact sheet owners learn how to use the tool and contribute data simultaneously. To learn more about the dashboard, see [Fact Sheet Owner Onboarding Dashboard](https://help.sap.com/docs/leanix/ea/fact-sheet-owner-onboarding-dashboard?locale=en-US&state=PRODUCTION&version=CLOUD "The Fact Sheet Owner onboarding dashboard helps new users learn SAP LeanIX. It offers resources and panels for understanding responsibilities, managing data, and collaborating. It's the default dashboard for new workspaces, featuring tutorials and links to product documentation.").
Before inviting users, configure the dashboard as needed. For example, you can create a saved search for applications marked as In scope and add it to the dashboard. To learn how to create a saved search, see [Saving Search Results](https://help.sap.com/docs/leanix/ea/searching-and-filtering-in-inventory?locale=en-US&state=PRODUCTION&version=CLOUD#loio275c8bfc7a441014bb2cc509aac188d0__saving_search_results).
To use the dashboard, users need to have access to your workspace. To learn more about managing user access, see [User and Access Management](https://help.sap.com/docs/leanix/ea/user-and-access-management?locale=en-US&state=PRODUCTION&version=CLOUD "Efficiently manage user access and authorization to ensure the right people have the appropriate permissions.").
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275425737a4410149682fedf7a586e82_LowRes.png)
Overview of the Application Portfolio on the Fact Sheet Owner Onboarding Dashboard
